#!/usr/bin/env python2

import pygame, sys, random
from pygame.locals import *

SCREENWIDTH = 1024
SCREENHEIGHT = 768
pygame.init()
#SCREEN = pygame.display.set_mode((SCREENWIDTH, SCREENHEIGHT), pygame.FULLSCREEN)
SCREEN = pygame.display.set_mode((SCREENWIDTH, SCREENHEIGHT), 0)
FONT = pygame.font.Font('freesansbold.ttf', 16)
FPSCLOCK = pygame.time.Clock()
FPS = 24
BLACK = (0, 0, 0)
WHITE = (255, 255, 255)

def menuText (pos, c1, c2, text):
	txtsurf = FONT.render(text, True, c1, c2)
	txtrect = txtsurf.get_rect()
	txtrect.topleft = ((pos[0], pos[1]))
	txt = SCREEN.blit(txtsurf, txtrect)
	return txt

def titleScreen ():
	done = False
	redo = True
	updates = []
	while not done:
		if redo:
			SCREEN.blit (pygame.image.load('background_title.png').convert(), (0, 0))
			pygame.display.update ()
			redo = False

		startButton = menuText ((0, 0), BLACK, WHITE, "Start")
		updates.append (startButton)
		infoButton = menuText ((0, 50), BLACK, WHITE, "Info")
		updates.append (infoButton)
		quitButton = menuText ((0, 100), BLACK, WHITE, "Quit")
		updates.append (quitButton)

		for event in pygame.event.get():
			if event.type == QUIT:
				sys.exit()
			elif event.type == MOUSEBUTTONDOWN:
				if startButton.collidepoint (event.pos):
					doGame ()
					redo = True
				elif infoButton.collidepoint (event.pos):
					infoScreen ()
					redo = True
				elif quitButton.collidepoint (event.pos):
					done = True
            			
		pygame.display.update (updates)
		updates = []
		FPSCLOCK.tick (FPS)

def infoScreen ():
	done = False
	updates = []
	SCREEN.blit (pygame.image.load('background_info.png').convert(), (0, 0))
	pygame.display.update ()
	while not done:		
		okButton = menuText ((0, 0), BLACK, WHITE, "OK")
		updates.append (okButton)

		for event in pygame.event.get():
			if event.type == QUIT:
				sys.exit()
			elif event.type == MOUSEBUTTONDOWN:
				if okButton.collidepoint (event.pos):
					done = True
            			
		pygame.display.update (updates)
		updates = []
		FPSCLOCK.tick (FPS)

def doWinScreen ():
	done = False
	updates = []
	SCREEN.blit (pygame.image.load('background_won.png').convert(), (0, 0))
	pygame.display.update ()
	while not done:		
		okButton = menuText ((0, 0), BLACK, WHITE, "OK")
		updates.append (okButton)

		for event in pygame.event.get():
			if event.type == QUIT:
				sys.exit()
			elif event.type == MOUSEBUTTONDOWN:
				if okButton.collidepoint (event.pos):
					done = True
            			
		pygame.display.update (updates)
		updates = []
		FPSCLOCK.tick (FPS)

def doLoseScreen ():
	done = False
	updates = []
	SCREEN.blit (pygame.image.load('background_lost.png').convert(), (0, 0))
	pygame.display.update ()
	while not done:		
		okButton = menuText ((0, 0), BLACK, WHITE, "OK")
		updates.append (okButton)

		for event in pygame.event.get():
			if event.type == QUIT:
				sys.exit()
			elif event.type == MOUSEBUTTONDOWN:
				if okButton.collidepoint (event.pos):
					done = True
            			
		pygame.display.update (updates)
		updates = []
		FPSCLOCK.tick (FPS)

def doDeathScreen ():
	done = False
	updates = []
	SCREEN.blit (pygame.image.load('background_died.png').convert(), (0, 0))
	pygame.display.update ()
	while not done:		
		okButton = menuText ((0, 0), BLACK, WHITE, "OK")
		updates.append (okButton)

		for event in pygame.event.get():
			if event.type == QUIT:
				sys.exit()
			elif event.type == MOUSEBUTTONDOWN:
				if okButton.collidepoint (event.pos):
					done = True
            			
		pygame.display.update (updates)
		updates = []
		FPSCLOCK.tick (FPS)

class Pad (pygame.sprite.DirtySprite):
	def __init__(self, x, y, img, groups):
		pygame.sprite.Sprite.__init__(self) 
		self.image = img
		self.groups = groups
		self.rect = self.image.get_rect()
		self.rect.x = x
		self.rect.y = y

class Star (pygame.sprite.DirtySprite):
	def __init__(self, x, y, img, groups):
		pygame.sprite.Sprite.__init__(self) 
		self.image = img
		self.groups = groups
		self.image.set_colorkey(BLACK)
		self.rect = self.image.get_rect()
		self.rect.x = x
		self.rect.y = y
	        
	def update (self):
		if random.randrange (10000) >= 9999:
			for g in self.groups:
				self.remove (g)
				
class Lander (pygame.sprite.DirtySprite):
	def __init__(self, x, img, groups):
		pygame.sprite.Sprite.__init__(self) 
		self.image = img
		self.groups = groups
		self.image.set_colorkey(WHITE)
		self.rect = self.image.get_rect()
		self.rect.x = x
		self.rect.y = 0
		self.fuel = 100 
		self.thrust_left = False
		self.thrust_right = False
		self.thrust_up = False
	        
	def update (self):
		# Should check if we are too far left or right...
		if self.fuel > 0:
			if self.thrust_left:
				self.rect.x = self.rect.x + 2
				self.fuel = self.fuel - 1
			if self.thrust_right:
				self.rect.x = self.rect.x - 2
				self.fuel = self.fuel - 1
			if self.thrust_up:
				self.rect.y = self.rect.y - 2
				self.fuel = self.fuel - 1
				# should check if we've flown off into space...
		else:
			self.thrust_left = False
			self.thrust_right = False
			self.thrust_up = False
			
		if self.thrust_up == False:
			self.rect.y = self.rect.y + 2
            
def game1 (lives):
	redo = True
	updates = []
	lander_img = pygame.image.load('lander.png').convert()
	pad_img = pygame.image.load('pad.png').convert()
	star_img = pygame.image.load('star.png').convert()
	done = False	
	
	while not done:
		if redo == True:
			background_img = pygame.image.load('background_game1.png').convert()
			SCREEN.blit (background_img, (0, 0))
			pygame.display.update ()
			star_sprites = pygame.sprite.RenderUpdates ()
			player_sprites = pygame.sprite.RenderUpdates ()
			all_sprites = pygame.sprite.RenderUpdates ()
			
			player = Lander (random.randrange(SCREENWIDTH), lander_img, [player_sprites, all_sprites])
			player_sprites.add (player)		
			all_sprites.add (player)		
			
			pad = Pad (320, 700, pad_img, [all_sprites])
			all_sprites.add (pad)			
			redo = False
		
		while len (star_sprites) < 50:
			star = Star (random.randrange(SCREENWIDTH), random.randrange(SCREENHEIGHT), star_img, [star_sprites, all_sprites])
			star_sprites.add (star)
			all_sprites.add (star)		
			
		if player.rect.bottom == pad.rect.top:
			if player.rect.left >= pad.rect.left:
				if player.rect.right <= pad.rect.right:
					done = True
		elif player.rect.bottom > pad.rect.top:
			lives = lives - 1
			redo = True

		for event in pygame.event.get():
			if event.type == QUIT:
				sys.exit()
		keys = pygame.key.get_pressed()  #checking pressed keys
		if keys[pygame.K_RIGHT]:
			player.thrust_left = True
		else:
			player.thrust_left = False
		if keys[pygame.K_LEFT]:
			player.thrust_right = True
		else:
			player.thrust_right = False
		if keys[pygame.K_UP]:
			player.thrust_up = True
		else:
			player.thrust_up = False

		all_sprites.clear (SCREEN, background_img)

		star_sprites.update ()
		player_sprites.update ()

		updates.extend (all_sprites.draw (SCREEN))
		
		updates.append (menuText ((0, 0), WHITE, BLACK, "Fuel " + str (player.fuel) + "%"))
		
		pygame.display.update (updates)
		updates = []
		FPSCLOCK.tick (FPS)
	return lives

def game2 (lives):
	return lives

def game3 (lives):
	return lives

def doGame ():
	lives = 5
	if lives > 0:
		lives = game1 (lives)
	if lives > 0:
		lives = game2 (lives)
	if lives > 0:
		lives = game3 (lives)
	if lives > 0:
		doWinScreen ()
	else:
		doLoseScreen ()

#titleScreen ()
print game1 (5)

pygame.quit()
sys.exit()

"""
Day 1:
Exciting - game theme chosen! Let's get started!
I decided to do a series of 'mini games' so I can complete each one and make as many more as time permits
Made an empty 'skeleton' game with placeholders for title screen, info screen, winning screen, losing screen, a death screen
Level 1 - land a lunar module on the moon
Spent longer on the random stars than I should have... especially as according to the NASA photos you can't see stars on the moon...
Todo:
Make proper backgrounds
Maybe sounds for button presses in menus
Make background stars varying sizes or at least smaller!

Day 2:

Day 3:

Day 4:

Day 5:

Day 6:

Day 7:

"""

"""
What have I used:
Archlinux
Geany
Python 2
Pygame
Gimp
"""
